@@ -1,9 +1,9 @@
-import pytest
-import struct
 import datetime
+import struct
+
+import pytest
 
 from schema_registry.client import schema
-
 from tests import data_gen
 
 
@@ -51,28 +51,21 @@ def test_encode_logical_types(client, message_serializer):
     message = message_serializer.encode_record_with_schema_id(schema_id, record)
 
     decoded = message_serializer.decode_message(message)
-    decoded_datetime = decoded.get("metadata").get("timestamp")
 
+    decoded_datetime = decoded.get("metadata").get("timestamp")
     timestamp = record.get("metadata").get("timestamp")
-    date_time = datetime.datetime.fromtimestamp(timestamp / 1000.0)
 
     decoded_total = decoded.get("metadata").get("total")
     total = record.get("metadata").get("total")
 
-    assert date_time == decoded_datetime.replace(tzinfo=None)
+    assert timestamp == decoded_datetime.replace(tzinfo=None)
     assert total == decoded_total
 
 
 def test_encode_decode_with_schema_from_json(message_serializer, deployment_schema):
-    deployment_record = {
-        "image": "registry.gitlab.com/my-project:1.0.0",
-        "replicas": 1,
-        "port": 8080,
-    }
+    deployment_record = {"image": "registry.gitlab.com/my-project:1.0.0", "replicas": 1, "port": 8080}
 
-    message_encoded = message_serializer.encode_record_with_schema(
-        "deployment", deployment_schema, deployment_record
-    )
+    message_encoded = message_serializer.encode_record_with_schema("deployment", deployment_schema, deployment_record)
 
     assert message_encoded
     assert len(message_encoded) > 5
@@ -84,16 +77,10 @@ def test_encode_decode_with_schema_from_json(message_serializer, deployment_sche
 
 
 def test_fail_encode_with_schema(message_serializer, deployment_schema):
-    bad_record = {
-        "image": "registry.gitlab.com/my-project:1.0.0",
-        "replicas": "1",
-        "port": "8080",
-    }
+    bad_record = {"image": "registry.gitlab.com/my-project:1.0.0", "replicas": "1", "port": "8080"}
 
     with pytest.raises(TypeError):
-        message_serializer.encode_record_with_schema(
-            "deployment", deployment_schema, bad_record
-        )
+        message_serializer.encode_record_with_schema("deployment", deployment_schema, bad_record)
 
 
 def test_encode_record_with_schema(client, message_serializer):
